@@ -6,6 +6,7 @@ Command to list YellowDog entities.
 
 from dataclasses import asdict, fields
 from json import loads as json_loads
+from os.path import exists
 from typing import Dict, List
 
 from requests import get
@@ -17,9 +18,7 @@ from yellowdog_client.model import (
     ComputeRequirement,
     ComputeRequirementSearch,
     ComputeRequirementStatus,
-    ComputeRequirementTemplate,
     ComputeRequirementTemplateSummary,
-    ComputeSourceTemplate,
     ComputeSourceTemplateSummary,
     Instance,
     InstanceSearch,
@@ -51,7 +50,7 @@ from yd_commands.entity_utils import (
     get_tasks,
     list_matching_object_paths,
 )
-from yd_commands.interactive import select
+from yd_commands.interactive import confirmed, select
 from yd_commands.printing import (
     indent,
     print_json,
@@ -60,7 +59,18 @@ from yd_commands.printing import (
     print_table_core,
     print_warning,
     print_yd_object,
+    print_yd_object_list,
     sorted_objects,
+    substitute_ids_for_names_in_crt,
+)
+from yd_commands.settings import (
+    RN_ALLOWANCE,
+    RN_IMAGE_FAMILY,
+    RN_KEYRING,
+    RN_NUMERIC_ATTRIBUTE_DEFINITION,
+    RN_REQUIREMENT_TEMPLATE,
+    RN_SOURCE_TEMPLATE,
+    RN_STRING_ATTRIBUTE_DEFINITION,
 )
 from yd_commands.utils import unpack_namespace_in_prefix
 from yd_commands.wrapper import ARGS_PARSER, CLIENT, CONFIG_COMMON, main_wrapper
@@ -74,6 +84,13 @@ def main():
     # Always use interactive mode for selections
     ARGS_PARSER.interactive = True
 
+    if ARGS_PARSER.output_file and ARGS_PARSER.details:
+        if exists(ARGS_PARSER.output_file):
+            if not confirmed(
+                f"Overwrite file '{ARGS_PARSER.output_file}' with resource details?"
+            ):
+                return
+
     if ARGS_PARSER.object_paths:
         list_object_paths()
     elif ARGS_PARSER.work_requirements or ARGS_PARSER.task_groups or ARGS_PARSER.tasks:
@@ -83,9 +100,9 @@ def main():
     elif ARGS_PARSER.compute_requirements or ARGS_PARSER.instances:
         list_compute_requirements()
     elif ARGS_PARSER.compute_templates:
-        list_compute_templates()
+        list_compute_requirement_templates()
     elif ARGS_PARSER.source_templates:
-        list_source_templates()
+        list_compute_source_templates()
     elif ARGS_PARSER.keyrings:
         list_keyrings()
     elif ARGS_PARSER.image_families:
@@ -446,7 +463,7 @@ def list_workers(nodes: List[Node]):
         print_yd_object(worker)
 
 
-def list_compute_templates():
+def list_compute_requirement_templates():
     """
     Print the list of Compute Requirement Templates, filtered on Namespace
     and Name. Set these both to empty strings to generate an unfiltered list.
@@ -472,15 +489,24 @@ def list_compute_templates():
         print_numbered_object_list(CLIENT, sorted_objects(cr_templates))
         return
 
+    # Show details
     cr_templates = select(CLIENT, cr_templates)
-    for cr_template in cr_templates:
-        cr_template_detail: ComputeRequirementTemplate = (
-            CLIENT.compute_client.get_compute_requirement_template(cr_template.id)
+    cr_template_details = [
+        (
+            substitute_ids_for_names_in_crt(
+                CLIENT,
+                CLIENT.compute_client.get_compute_requirement_template(cr_template.id),
+            ),
+            RN_REQUIREMENT_TEMPLATE,
         )
-        print_yd_object(cr_template_detail)
+        for cr_template in cr_templates
+    ]
+    print_yd_object_list(
+        cr_template_details,
+    )
 
 
-def list_source_templates():
+def list_compute_source_templates():
     """
     Print the list of Compute Source Templates, filtered on Namespace
     and Name. Set these both to empty strings to generate an unfiltered list.
@@ -506,12 +532,18 @@ def list_source_templates():
         print_numbered_object_list(CLIENT, sorted_objects(cs_templates))
         return
 
+    # Show details
     cs_templates = select(CLIENT, sorted_objects(cs_templates))
-    for cs_template in cs_templates:
-        cs_template_detail: ComputeSourceTemplate = (
-            CLIENT.compute_client.get_compute_source_template(cs_template.id)
+    cs_template_details = [
+        (
+            CLIENT.compute_client.get_compute_source_template(cs_template.id),
+            RN_SOURCE_TEMPLATE,
         )
-        print_yd_object(cs_template_detail)
+        for cs_template in cs_templates
+    ]
+    print_yd_object_list(
+        cs_template_details,
+    )
 
 
 def list_keyrings():
@@ -526,9 +558,10 @@ def list_keyrings():
         print_numbered_object_list(CLIENT, sorted_objects(keyrings))
         return
 
-    keyrings = select(CLIENT, keyrings)
-    for keyring_summary in keyrings:
-        print_yd_object(get_keyring(keyring_summary.name))
+    # Show details
+    print_yd_object_list(
+        [(keyring, RN_KEYRING) for keyring in select(CLIENT, keyrings)]
+    )
 
 
 def get_keyring(name: str) -> Keyring:
@@ -567,11 +600,18 @@ def list_image_families():
         print_numbered_object_list(CLIENT, sorted_objects(image_family_summaries))
         return
 
-    for image_family_summary in select(CLIENT, sorted_objects(image_family_summaries)):
-        image_family = CLIENT.images_client.get_image_family_by_id(
-            image_family_summary.id
+    # Show details
+    image_family_summaries = select(CLIENT, sorted_objects(image_family_summaries))
+    image_families = [
+        (
+            CLIENT.images_client.get_image_family_by_id(image_family_summary.id),
+            RN_IMAGE_FAMILY,
         )
-        print_yd_object(image_family)
+        for image_family_summary in image_family_summaries
+    ]
+    print_yd_object_list(
+        image_families,
+    )
 
 
 def list_namespaces():
@@ -656,8 +696,10 @@ def list_allowances():
         print_numbered_object_list(CLIENT, allowances)
         return
 
-    for allowance in select(CLIENT, allowances):
-        print_yd_object(allowance)
+    # Show details
+    print_yd_object_list(
+        [(allowance, RN_ALLOWANCE) for allowance in select(CLIENT, allowances)]
+    )
 
 
 def list_attribute_definitions():
@@ -684,13 +726,24 @@ def list_attribute_definitions():
         )
         return
 
-    for selected_attribute_definition in select(
-        CLIENT,
-        attribute_definition_list,
-        object_type_name="Attribute Definition",
-        sort_objects=False,
-    ):
-        print_json(selected_attribute_definition)
+    # Show details
+    attribute_definition_list = [
+        (
+            attribute,
+            (
+                RN_NUMERIC_ATTRIBUTE_DEFINITION
+                if "Numeric" in attribute["type"]
+                else RN_STRING_ATTRIBUTE_DEFINITION
+            ),
+        )
+        for attribute in select(
+            CLIENT,
+            attribute_definition_list,
+            object_type_name="Attribute Definition",
+            sort_objects=False,
+        )
+    ]
+    print_yd_object_list(attribute_definition_list)
 
 
 def list_namespace_policies():
