@@ -1,28 +1,26 @@
 #!/usr/bin/env python3
 
 """
-A script to shut down Worker Pools.
+A script to shut down Worker Pools and/or Nodes.
 """
 
 from typing import List
 
 from yellowdog_client.model import WorkerPool, WorkerPoolStatus, WorkerPoolSummary
 
+from yd_commands.entity_utils import get_worker_pool_by_id, get_worker_pool_id_by_name
 from yd_commands.follow_utils import follow_ids
 from yd_commands.interactive import confirmed, select
-from yd_commands.object_utilities import (
-    get_worker_pool_by_id,
-    get_worker_pool_id_by_name,
-)
 from yd_commands.printing import print_error, print_log
 from yd_commands.utils import link_entity
 from yd_commands.wrapper import ARGS_PARSER, CLIENT, CONFIG_COMMON, main_wrapper
+from yd_commands.ydid_utils import YDIDType, get_ydid_type
 
 
 @main_wrapper
 def main():
-    if len(ARGS_PARSER.worker_pool_list) > 0:
-        shutdown_by_names_or_ids(ARGS_PARSER.worker_pool_list)
+    if len(ARGS_PARSER.worker_pool_nodes_list) > 0:
+        shutdown_by_names_or_ids(ARGS_PARSER.worker_pool_nodes_list)
         return
 
     print_log(
@@ -81,11 +79,15 @@ def main():
 
 def shutdown_by_names_or_ids(names_or_ids: List[str]):
     """
-    Shutdown Worker Pools by their names or IDs.
+    Shutdown Worker Pools and/or Nodes by their names or IDs.
     """
     worker_pool_ids: List[str] = []
+    node_ids: List[str] = []
     for name_or_id in names_or_ids:
-        if "ydid:wrkrpool:" in name_or_id:
+        if get_ydid_type(name_or_id) == YDIDType.NODE:
+            node_ids.append(name_or_id)
+            continue
+        if get_ydid_type(name_or_id) == YDIDType.WORKER_POOL:
             worker_pool_id = name_or_id
         else:
             worker_pool_id = get_worker_pool_id_by_name(CLIENT, name_or_id)
@@ -94,11 +96,13 @@ def shutdown_by_names_or_ids(names_or_ids: List[str]):
                 continue
         worker_pool_ids.append(worker_pool_id)
 
-    if len(worker_pool_ids) == 0:
-        print_log("No Worker Pools to shut down")
+    if len(worker_pool_ids) == 0 and len(node_ids) == 0:
+        print_log("No Worker Pools or Nodes to shut down")
         return
 
-    if not confirmed(f"Shut down {len(worker_pool_ids)} Worker Pool(s)?"):
+    if not confirmed(
+        f"Shut down {len(worker_pool_ids) + len(node_ids)} Worker Pool(s) and/or Node(s)?"
+    ):
         return
 
     for worker_pool_id in worker_pool_ids:
@@ -108,6 +112,13 @@ def shutdown_by_names_or_ids(names_or_ids: List[str]):
         except Exception as e:
             print_error(f"Unable to shut down Worker Pool '{worker_pool_id}': ({e})")
 
+    for node_id in node_ids:
+        try:
+            CLIENT.worker_pool_client.shutdown_node_by_id(node_id)
+            print_log(f"Shut down Node '{node_id}'")
+        except Exception as e:
+            print_error(f"Unable to shut down Node '{node_id}': ({e})")
+
     if ARGS_PARSER.follow:
         follow_ids(worker_pool_ids, auto_cr=ARGS_PARSER.auto_cr)
 
